@@ -1,4 +1,4 @@
-from EasyFrames.easyframes import easyframes
+from easyframes.easyframes import hhkit
 
 df_original = pd.read_csv('sample_hh_dataset.csv')
 df = df_original.copy()
